pitchtools.list_melodic_chromatic_interval_numbers_pairwise_between_pitch_carriers
==================================================================================

.. autofunction:: abjad.tools.pitchtools.list_melodic_chromatic_interval_numbers_pairwise_between_pitch_carriers.list_melodic_chromatic_interval_numbers_pairwise_between_pitch_carriers
